@@ -33,13 +33,14 @@ class SNSClientExtended(object):
 
     """
 
-    def __init__(self, aws_access_key_id=None, aws_secret_access_key=None, aws_region_name=None, s3_bucket_name=None):
+    def __init__(self, aws_access_key_id=None, aws_secret_access_key=None, 
+                 aws_region_name=None, s3_bucket_name=None, always_through_s3=False):
         self.aws_access_key_id = aws_access_key_id
         self.aws_secret_access_key = aws_secret_access_key
         self.aws_region_name = aws_region_name
         self.s3_bucket_name = s3_bucket_name
         self.message_size_threshold = SQSExtendedClientConstants.DEFAULT_MESSAGE_SIZE_THRESHOLD.value
-        self.always_through_s3 = True
+        self.always_through_s3 = always_through_s3
         if aws_access_key_id and aws_secret_access_key and aws_region_name:
             self.sns = boto3.client(
                 'sns',
